mafw.decorators
===============

.. automodule:: mafw.decorators

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      single_loop
      for_loop
      while_loop
   
   .. rubric:: Functions

   .. autosummary::
   
      database_required
      depends_on_optional
      execution_workflow
      for_loop
      orphan_protector
      processor_depends_on_optional
      single_loop
      singleton
      while_loop
   